# -*- coding: utf-8 -*-

class Status14Enum(object):

    """Implementation of the 'Status14' enum.

    Specifies the status of the recovery.

    Attributes:
        RUNNING: TODO: type description here.
        ACCEPTED: TODO: type description here.
        CANCELED: TODO: type description here.
        CANCELING: TODO: type description here.
        FAILED: TODO: type description here.
        MISSED: TODO: type description here.
        SUCCEEDED: TODO: type description here.
        SUCCEEDEDWITHWARNING: TODO: type description here.
        ONHOLD: TODO: type description here.

    """

    ACCEPTED = 'Accepted'

    RUNNING = 'Running'

    CANCELED = 'Canceled'

    CANCELING = 'Canceling'

    FAILED = 'Failed'

    MISSED = 'Missed'

    SUCCEEDED = 'Succeeded'

    SUCCEEDEDWITHWARNING = 'SucceededWithWarning'

    ONHOLD = 'OnHold'

